@@ -12,14 +12,16 @@
 namespace hyperflux {
 
 struct UniformFluxSamplingSettings : public samply::Settings {
-	// Nothing interesting for now :)
-	UniformFluxSamplingSettings() = default;
-	UniformFluxSamplingSettings(const UniformFluxSamplingSettings&) = default;
+    // Nothing interesting for now :)
+    UniformFluxSamplingSettings() = default;
+    UniformFluxSamplingSettings(const UniformFluxSamplingSettings&) = default;
 
-	UniformFluxSamplingSettings(const samply::Settings base_settings)
-		: samply::Settings(base_settings) {}
+    UniformFluxSamplingSettings(const samply::Settings base_settings)
+        : samply::Settings(base_settings)
+    {
+    }
 };
 
-} // namespace hyperflux
+}  // namespace hyperflux
 
 #endif
\ No newline at end of file
